@@ -3,7 +3,7 @@
 # @Author: floepi
 # @Date:   2015-06-04 17:42:44
 # @Last Modified by:   Brady Endres
-# @Last Modified time: 2021-05-11
+# @Last Modified time: 2021-06-08
 #!/usr/local/bin/python
 
 from __future__ import absolute_import, division, print_function
@@ -253,6 +253,14 @@ class SyncSketchAPI:
         """
         return self._get_json_response("project/%s" % project_id)
 
+    def get_project_storage(self, project_id):
+        """
+        Get project storage usage in bytes
+        :param project_id: Number
+        :return:
+        """
+        return self._get_json_response("project/%s/storage" % project_id, api_version="v2")
+
     def update_project(self, project_id, data):
         """
         Update a project
@@ -370,6 +378,14 @@ class SyncSketchAPI:
         """
         return self._get_json_response("review/%s" % review_id)
 
+    def get_review_storage(self, review_id):
+        """
+        Get review storage usage in bytes
+        :param review_id: Number
+        :return:
+        """
+        return self._get_json_response("review/%s/storage" % review_id, api_version="v2")
+
     def update_review(self, review_id, data):
         """
         Update a review
